==> style-o-matic-1.1.37.tgz: package/es/components/Nav/NavFolder.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { cloneElement } from "react";
import classNames from "classnames";
import { CoreComponent, getCorePropDefaults, getCorePropTypes, getValidProps, UIGlobals, ROLE } from "../../lib";

var NavFolder = (_temp = _class = function (_CoreComponent) {
  _inherits(NavFolder, _CoreComponent);

  function NavFolder(props) {
    _classCallCheck(this, NavFolder);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props));

    _initialiseProps.call(_this);

    _this.useParentNode = true;
    _this.state = {
      expanded: "",
      offset: {}
    };
    return _this;
  }

  NavFolder.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        uiclass = _getValidProps.uiclass,
        className = _getValidProps.className,
        to = _getValidProps.to,
        path = _getValidProps.path,
        text = _getValidProps.text,
        icon = _getValidProps.icon,
        minimized = _getValidProps.minimized,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    var _state = this.state,
        offset = _state.offset,
        expanded = _state.expanded;


    var classes = {
      expanded: expanded,
      minimized: minimized,
      active: to && path.indexOf(to) !== -1
    };

    var caretClass = !minimized && expanded ? "fa fa-caret-down" : "fa fa-caret-right";

    return React.createElement(
      "div",
      {
        className: "ui-nav-flyout-wrapper",
        ref: this.onSetRef,
        onMouseEnter: this.handleMouseEnter
      },
      React.createElement(
        "a",
        { className: "ui-nav-item", href: to, label: text },
        React.createElement("i", { className: "ui-nav-item-icon " + icon }),
        React.createElement(
          "span",
          { className: "ui-nav-item-info" },
          text
        ),
        React.createElement("span", {
          className: "ui-nav-item-caret " + caretClass,
          role: "presentation",
          onKeyDown: this.toggleExpansion,
          onClick: this.toggleExpansion
        })
      ),
      React.createElement(
        Component,
        _extends({}, props, {
          className: classNames(className, classes),
          style: offset
        }),
        React.createElement(
          "div",
          { className: "ui-nav-folder-title" },
          text
        ),
        React.Children.map(children, function (child) {
          if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined") {
            return _this2.renderChild(child, inherited);
          }
          return child;
        })
      )
    );
  };

  return NavFolder;
}(CoreComponent), _class.propTypes = getCorePropTypes({
  minimized: "bool"
}), _class.defaultProps = getCorePropDefaults({
  uirole: ROLE.FOLDER,
  text: "",
  minimized: false
}), _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.handleMouseEnter = function (e) {
    if (_this3.node) {
      var _UIGlobals$getScreenD = UIGlobals.getScreenDimensions(),
          screenBottom = _UIGlobals$getScreenD.bottom,
          screenHeight = _UIGlobals$getScreenD.height,
          screenWidth = _UIGlobals$getScreenD.width;

      var _node$getBoundingClie = _this3.node.getBoundingClientRect(),
          x = _node$getBoundingClie.x,
          y = _node$getBoundingClie.y,
          height = _node$getBoundingClie.height,
          bottom = _node$getBoundingClie.bottom;

      var offset = {};
      if (y > screenHeight / 2) {
        var bottomOffset = 0;
        bottomOffset = height / 2;
        bottomOffset += screenHeight;
        bottomOffset -= bottom;
        offset.bottom = bottomOffset + "px";
      }
      if (x > screenWidth / 2) {
        offset.right = "0px";
      }
      _this3.setState({ offset: offset });
    }
  };

  this.toggleExpansion = function (e) {
    e.preventDefault();
    if (!_this3.props.minimized) {
      _this3.setState({ expanded: !_this3.state.expanded });
    }
  };

  this.renderChild = function (child, props) {
    var role = child.props.uirole || ROLE.ITEM;
    var ref = function ref(c) {
      _this3[role] = c;
    };
    if (typeof child.ref !== "string") {
      ref = _this3.chainFunction(child.ref, ref);
    }
    return cloneElement(child, _extends({}, props, {
      ref: ref,
      uiclass: _this3.childPrefix(role),
      onClick: _this3.chainFunction(child.props.onClick, _this3.handleOnClick)
    }));
  };
}, _temp);


export default NavFolder;

==> style-o-matic-1.2.0.tgz: package/es/components/Nav/NavFolder.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp, _initialiseProps;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

/**
 * @memberof components
 * @todo Write sub-component documentation
 * @author Steven Jackson
 */
import React, { cloneElement } from "react";
import classNames from "classnames";
import activeElement from "dom-helpers/activeElement";
import contains from "dom-helpers/query/contains";
import { CoreComponent, setCorePropDefaults, setCorePropTypes, getValidProps, UIGlobals, ROLE } from "../../lib";

var NavFolder = (_temp = _class = function (_CoreComponent) {
  _inherits(NavFolder, _CoreComponent);

  function NavFolder(props) {
    _classCallCheck(this, NavFolder);

    var _this = _possibleConstructorReturn(this, _CoreComponent.call(this, props));

    _initialiseProps.call(_this);

    _this.folder = null;
    _this.state = {
      closed: props.closed
    };
    return _this;
  }

  NavFolder.prototype.render = function render() {
    var _this2 = this;

    var _getValidProps = getValidProps(this.props),
        Component = _getValidProps.renderAs,
        uiclass = _getValidProps.uiclass,
        coreClassName = _getValidProps.coreClassName,
        iconClassName = _getValidProps.iconClassName,
        to = _getValidProps.to,
        path = _getValidProps.path,
        label = _getValidProps.label,
        children = _getValidProps.children,
        props = _getValidProps.props,
        inherited = _getValidProps.inherited;

    var closed = this.state.closed;


    var classes = {
      "ui--closed": closed,
      active: to && path.indexOf(to) !== -1
    };

    var itemClass = closed ? "ui-nav-item" : "ui-nav-item ui--open";
    return React.createElement(
      "li",
      { className: itemClass, ref: this.onSetRef },
      React.createElement(
        "div",
        {
          className: "ui-nav-caret",
          role: "presentation",
          onKeyDown: this.toggleExpansion,
          onClick: this.toggleExpansion
        },
        label
      ),
      React.createElement(
        Component,
        _extends({}, props, { className: classNames(coreClassName, classes) }),
        React.createElement(
          "h5",
          { className: "ui-nav-title" },
          label
        ),
        React.Children.map(children, function (child) {
          if (typeof child.props !== "undefined" && typeof child.props.uirole !== "undefined" && child.props.uirole === ROLE.ITEM) {
            return _this2.renderChild(child, _extends({
              label: label
            }, inherited));
          }
          return child;
        })
      )
    );
  };

  return NavFolder;
}(CoreComponent), _class.propTypes = setCorePropTypes({
  minimized: "bool"
}), _class.defaultProps = setCorePropDefaults({
  renderAs: "ul",
  uirole: ROLE.FOLDER,
  uigroup: ROLE.NAV,
  label: ""
}), _initialiseProps = function _initialiseProps() {
  var _this3 = this;

  this.toggleExpansion = function (e) {
    e.preventDefault();
    var newState = _this3.state;
    newState.closed = !newState.closed;
    _this3.setState(newState);
  };

  this.renderChild = function (child, props) {
    var role = child.props.uirole || ROLE.ITEM;
    var ref = function ref(c) {
      _this3[role] = c;
    };
    if (typeof child.ref !== "string") {
      ref = _this3.chainFunction(child.ref, ref);
    }
    return cloneElement(child, _extends({}, props, {
      ref: ref,
      uirole: ROLE.FOLDERITEM,
      uiclass: _this3.childPrefix(role)
    }));
  };
}, _temp);


export default NavFolder;
